pub struct MethodDef<'a>(/* private fields */);Implementations
Sourceimpl<'a> MethodDef<'a>
impl<'a> MethodDef<'a>
pub fn impl_flags(&self) -> MethodImplAttributes
pub fn flags(&self) -> MethodAttributes
pub fn name(&self) -> &'a str
pub fn signature(&self, generics: &[Type]) -> Signature
Sourcepub fn params(&self) -> RowIterator<'a, MethodParam<'a>> ⓘ
pub fn params(&self) -> RowIterator<'a, MethodParam<'a>> ⓘ
Iterates the method’s Param rows in physical table order.
Use Self::params_by_sequence when associating rows with signature positions.
Sourcepub fn params_by_sequence(
&self,
parameter_count: usize,
) -> Result<MethodParamMap<'a>, MethodParamSequenceError>
pub fn params_by_sequence( &self, parameter_count: usize, ) -> Result<MethodParamMap<'a>, MethodParamSequenceError>
Associates Param rows with parameter_count signature positions.
Sequence zero is returned separately, nonzero sequences are one-based, and missing rows
remain None. Sparse and out-of-order rows are valid. Duplicate sequences and nonzero
sequences outside the signature are reported as errors. If several rows are invalid, the
first invalid row in physical table order is reported.
pub fn parent(&self) -> MemberRefParent<'a>
pub fn impl_map(&self) -> Option<ImplMap<'a>>
pub fn calling_convention(&self) -> &'static str